"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLocation = exports.sendDataWithImg = exports.getOsInfo = void 0;
var types_1 = require("../types");
var index_1 = require("./index");
var location_1 = require("./location");
/**
 * 获取操作系统 和 浏览器 信息
 *
 * @export
 * @returns os 操作系统名字 ver 操作系统版本号
 */
function getOsInfo() {
    var ua = window.navigator.userAgent.toLowerCase();
    var isAndroid = ua.match(/android/gi);
    var isIos = ua.match(/iphone|ipod|ipad/gi);
    var isWindows = ua.match(/windows/gi);
    var isMac = ua.match(/macintosh|mac os x/i);
    var isMobile = isAndroid || isIos;
    var os = '';
    var osVersion = '';
    if (isAndroid) {
        os = 'Android';
        var index = ua.indexOf('android');
        osVersion = String(parseFloat(ua.slice(index + 8)));
    }
    else if (isIos) {
        os = 'IOS';
        var info = ua.match(/cpu iphone os (.*?) like mac os/) || [];
        osVersion = String(info.length && info[1].replace(/_/g, '.'));
    }
    else if (isMac) {
        os = 'Mac';
        var info = ua.split('mac os x ')[1].split(' ')[0];
        osVersion = info
            .substr(0, 8)
            .replace(')', '')
            .replace(/_/g, '.');
    }
    else if (isWindows) {
        os = 'Windows';
        var index = ua.indexOf('windows');
        osVersion = String(parseFloat(ua.slice(index + 11)));
    }
    else {
        os = 'unknow';
        osVersion = 'unknow';
    }
    // PC需要返回浏览器信息
    var browser = '';
    var browserVersion = '';
    if (!isMobile) {
        var info_1 = {
            IE: /tablet|msie/.test(ua) && !/opera/.test(ua),
            Opera: /opera/.test(ua),
            Safari: /version.*safari/.test(ua),
            Chrome: /chrome/.test(ua),
            Firefox: /gecko/.test(ua) && !/webkit/.test(ua) // 匹配Firefox浏览器
        };
        var browserInfo = Object.keys(info_1).filter(function (browser) { return info_1[browser]; });
        if (browserInfo.length) {
            browser = browserInfo[0];
            if (browser === 'IE') {
                if (ua.indexOf('msie') > -1) {
                    var index = ua.indexOf('msie');
                    browserVersion = String(parseFloat(ua.substring(index + 5, ua.indexOf(';', index))));
                }
                else {
                    var index = ua.indexOf('rv:');
                    browserVersion = String(parseFloat(ua.substring(index + 3)));
                }
            }
            else {
                var index = ua.indexOf(browser.toLowerCase() + "/");
                console.info(ua, index);
                browserVersion = String(parseFloat(ua.slice(index + browser.length + 1))) || '';
            }
        }
        else {
            browser = 'unknow';
            browserVersion = 'unknow';
        }
    }
    var obj = {
        isMobile: isMobile,
        os: os,
        osVersion: osVersion,
        browser: browser,
        browserVersion: browserVersion
    };
    return obj;
}
exports.getOsInfo = getOsInfo;
/**
 * 使用图片的请求方式
 *
 * @export
 * @param {string} id
 * @param {string} url
 * @param {UserEvent} data
 */
function sendDataWithImg(id, url, data, debug) {
    if (debug === void 0) { debug = false; }
    if (index_1.checkPropertyKey(data.properties)) {
        var img_1 = new Image();
        img_1.crossOrigin = 'anonymous';
        var key_1 = 'img_log_' + Math.floor(Math.random() * 2147483648).toString(36); // 为本次数据请求创建一个唯一id
        window[key_1] = img_1;
        img_1.onload = img_1.onerror = img_1.onabort = function () {
            img_1.onload = img_1.onerror = img_1.onabort = null; // 清除img元素
            window[key_1] = null;
            img_1 = null;
        };
        var fetchUrl = url + "?data=" + encodeURIComponent(JSON.stringify(data)) + "&project_id=" + id + "&type=" + types_1.Constants.LIBRARY_JS;
        // 开启调试时传入
        if (debug) {
            fetchUrl += '&debug=true';
        }
        img_1.src = fetchUrl;
    }
}
exports.sendDataWithImg = sendDataWithImg;
/**
 * 获取经纬度
 *
 * @export
 * @returns {Promise<PositionInfo>}
 */
function getLocation() {
    return new Promise(function (resolve) {
        var options = {
            enableHighAccuracy: true,
            maximumAge: 0
        };
        if (navigator.geolocation) {
            navigator.geolocation.getCurrentPosition(function (position) {
                var bdInfo = location_1.wgs84tobd09(position.coords.longitude, position.coords.latitude);
                resolve({
                    longitude: bdInfo.longitude,
                    latitude: bdInfo.latitude
                });
            }, function (error) {
                console.warn(error.message);
                resolve({
                    longitude: undefined,
                    latitude: undefined
                });
            }, options);
        }
        else {
            resolve({
                longitude: undefined,
                latitude: undefined
            });
        }
    });
}
exports.getLocation = getLocation;
//# sourceMappingURL=browser.js.map