"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.compareVersion = exports.checkPropertyKey = exports.generateUUID = void 0;
/**
 * 生成UUID
 *
 * @export
 * @param {LibrayType} [sdkType='js']
 * @returns {string}
 */
function generateUUID(sdkType) {
    if (sdkType === void 0) { sdkType = 'js'; }
    var d = new Date().getTime();
    var uuid = 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function (c) {
        var r = (d + Math.random() * 16) % 16 | 0;
        d = Math.floor(d / 16);
        return (c === 'x' ? r : (r & 0x3) | 0x8).toString(16);
    });
    return sdkType + "_" + uuid;
}
exports.generateUUID = generateUUID;
/**
 * 校验数据格式是否正确
 *
 * @export
 * @param {object} data
 * @returns {boolean} 是否通过校验
 */
function checkPropertyKey(data) {
    var reg = /^([a-zA-Z][a-zA-Z_0-9]{0,49}$)/;
    var isPass = true;
    Object.keys(data).forEach(function (key) {
        if (!reg.test(key)) {
            isPass = false;
            throw new Error("\u6570\u636E\u683C\u5F0F\u6821\u9A8C\u5931\u8D25\uFF0C\u5C5E\u6027 " + key + " \u4E0D\u7B26\u5408\u89C4\u5219\uFF1A\u4EE5\u5B57\u6BCD\u5F00\u5934\uFF0C\u53EF\u5305\u542B\u5B57\u6BCD\u3001\u6570\u503C\u3001\u4E0B\u5212\u7EBF\uFF0C\u4E14\u957F\u5EA6\u4E0D\u8D85\u8FC750");
        }
    });
    return isPass;
}
exports.checkPropertyKey = checkPropertyKey;
/**
 * 版本号比较
 *
 * @param {string} curV 当前版本号
 * @param {string} reqV 比较版本号
 * @returns curV > reqV
 */
exports.compareVersion = function (curV, reqV) {
    if (curV && reqV) {
        var arr1 = curV.split('.');
        var arr2 = reqV.split('.');
        var minLength = Math.min(arr1.length, arr2.length);
        var position = 0;
        var diff = 0;
        while (position < minLength && diff === 0) {
            position++;
            diff = parseInt(arr1[position]) - parseInt(arr2[position]);
        }
        diff = diff !== 0 ? diff : arr1.length - arr2.length;
        return diff > 0;
    }
    else {
        console.warn('版本号不能为空');
        return false;
    }
};
//# sourceMappingURL=index.js.map