import { InitOption } from '../types';
export default class JueXiaoMiniStatSDK {
    private sdkVersion;
    private sdkType;
    /** 项目唯一标识 */
    private projectId;
    private source;
    private isDebug;
    private trackTimes;
    private trackData;
    private initProperties;
    /**
     * Creates an instance of JueXiaoMiniStatSDK.
     * @param {InitOption} options
     * @memberof JueXiaoMiniStatSDK
     */
    constructor(options: InitOption);
    private init;
    private initPosition;
    /**
     * 初始化UUID
     *
     * @private
     * @returns {string}
     * @memberof JueXiaoMiniStatSDK
     */
    private initUserId;
    private _trackEvent;
    track(eventName: string, data?: {}): void;
    /**
     * 设置预置属性 已存在的字段则覆盖，不存在则自动创建
     *
     * @param {*} [options={}]
     * @memberof JueXiaoMiniStatSDK
     */
    profileSet(options?: object): void;
    /**
     * 设置用户首次属性，与 profileSet 不同的是，如果被设置的用户属性已存在，则这条记录会被忽略，如果属性不存在则会自动创建
     *
     * @param {object} options
     * @memberof JueXiaoMiniStatSDK
     */
    profileSetOnce(options?: object): void;
    /**
     * 获取session_id
     *
     * @private
     * @returns {string}
     * @memberof JueXiaoBrowserStatSDK
     */
    private getSessionId;
    /**
     * 注册预置属性
     *
     * @private
     * @param {Object} params
     * @memberof JueXiaoMiniStatSDK
     */
    private registerPresetProperties;
    /**
     * 用户注册-用于绑定登录id和匿名id之间的操作
     *
     * @param {string} loginId 用户注册成功后返回的userid
     * @memberof JueXiaoMiniStatSDK
     */
    trackSignUp(loginId: string): void;
    /**
     * 用户登录 - 用于更新用户id
     *
     * @param {string}
     * @memberof JueXiaoMiniStatSDK
     */
    login(loginId: string): void;
    /**
     * 退出登录
     *
     * @memberof JueXiaoMiniStatSDK
     */
    logout(): Promise<void>;
    /**
     * 设置公共属性，设置后每次上报都会带有设置的属性
     *
     * @param {*} [params={}]
     * @memberof JueXiaoBrowserStatSDK
     */
    setPublicProperties(params?: object): void;
    /**
     * 上传opendid
     *
     * 为了提高数据的准确性，小程序需要在运行时从服务端获取 openid 和 unionid
     *
     * 注意：openid一定能获取到，unionid在用户从未登录授权过公众号时无法获取到
     * @param {string} openid
     * @memberof JueXiaoMiniStatSDK
     */
    setOpenid(openid: string): void;
    /**
     * 上传unionid
     *
     * 为了提高数据的准确性，小程序需要在运行时从服务端获取 openid 和 unionid
     *
     * 注意：openid一定能获取到，unionid在用户从未登录授权过公众号时无法获取到
     * @param {string} unionid
     * @memberof JueXiaoMiniStatSDK
     */
    setUnionid(unionid: string): void;
}
